from setuptools import find_packages,setup

setup(name='houhou',
      py_modules=['.etsy'],
      version='0.0.3',
      description='This is for my own use',
      author='hhh',
      author_email='',
      packages=find_packages(),
      )